@@ -68,18 +68,21 @@
 #' fa_parallel(items, threshold = "mean") # traditional Horn's method
 #' }
 #'
-#' @author Jan Netik \cr Institute of Computer Science of the Czech Academy of
-#'   Sciences
+#' @author
+#' Jan Netik \cr
+#' Institute of Computer Science of the Czech Academy of Sciences \cr
+#' \email{netik@@cs.cas.cz}
 #'
-#'   Patricia Martinkova \cr Institute of Computer Science of the Czech Academy
-#'   of Sciences \cr \email{martinkova@@cs.cas.cz}
+#' Patricia Martinkova \cr
+#' Institute of Computer Science of the Czech Academy of Sciences \cr
+#' \email{martinkova@@cs.cas.cz}
 #'
-#' @references Horn, J. L. (1965). A rationale and test for the number of
-#'   factors in factor analysis. Psychometrika, 30, 179--185.
-#'   \doi{10.1007/BF02289447}
+#' @references
+#' Horn, J. L. (1965). A rationale and test for the number of factors in factor
+#' analysis. Psychometrika, 30, 179--185. \doi{10.1007/BF02289447}
 #'
-#'   Buja, A., & Eyuboglu, N. (1992). Remarks on parallel analysis. Multivariate
-#'   Behavioral Research, 27, 509--540. \doi{10.1207/s15327906mbr2704_2}
+#' Buja, A., & Eyuboglu, N. (1992). Remarks on parallel analysis. Multivariate
+#' Behavioral Research, 27, 509--540. \doi{10.1207/s15327906mbr2704_2}
 #'
 #' @encoding UTF-8
 #'
@@ -128,11 +131,10 @@ fa_parallel <- function(Data, cor = "pearson", n_obs = NULL,
       "pearson" = cor(Data, use = use),
       "polychoric" = tryCatch(polychoric(Data, na.rm = TRUE, ...)$rho,
         error = function(e) {
-          stop(
-            "Your items have more than 8 response categories, use of polychoric corr. is discouraged.\n",
-            "Choose different correlation or stick with polychoric by specifying `max.cat = n`,\n",
-            "where `n` is greater than the number of response categories of your items.",
-            call. = FALSE
+          stop(paste(
+            "Calculation of polychoric correlations returned an error:\n", e
+          ),
+          call. = FALSE
           )
         }
       ),
