@@ -1,7 +1,7 @@
 .onAttach <- function(libname, pkgname) {
   packageStartupMessage(
     paste("This is ShinyItemAnalysis version "), packageVersion("ShinyItemAnalysis"),
-    "\nTo run interactive shiny app, print startShinyItemAnalysis()",
-    "\nTo learn more, visit www.ShinyItemAnalysis.org"
+    "\n- to run the interactive {shiny} app, call `run_app()`",
+    "\n- to learn more, visit \"www.ShinyItemAnalysis.org\""
   )
 }
